# dijkstra-s-shortest-path

This library implements Dijkstra's shortest path algorithm(sp.py):
which uses a min-heap to store the shortest known distances from the source, the algorithm repeats until the heap becomes empty. At the end of the loop the array of distances should have the lowest costs to reach each of the destinations from the source.